const leftPanel = document.getElementById('leftPanels')
const shouldHide = !leftPanel || leftPanel.childElementCount === 0;
console.log(shouldHide)
if (shouldHide) {
  if (leftPanel) {
    leftPanel.style.display = 'none';
  }
  const contentPanel = document.querySelector('#contentcolumn > .main');
  if (contentPanel) {
    contentPanel.style.setProperty('margin-left', 0, 'important')
  }
}
if (shouldHide) {
  const bottomPanel = document.getElementById('xwikidatacontents');
  if (bottomPanel) {
    bottomPanel.style.display = 'none';
  }
}
const testPattern = /^\[[+-]?\d+(\.\d+)?\]/;

function replaceNodeText(from) {
  if (from.nodeType === 3) {
    const text = from.textContent;
    if (testPattern.test(text)) {
      from.textContent = text.replace(testPattern, "").trim();
    }
  } else if (from.childNodes) {
    for (const element of from.childNodes) {
      replaceNodeText(element);
    }
  }
}

function lookupAndReplaceText(parent) {
  parent.querySelectorAll('li.jstree-node').forEach((treeItem) => {
    const labelItem = treeItem.querySelector(".jstree-anchor");
    if (labelItem) {
      replaceNodeText(labelItem);
    }
    const childrenItem = treeItem.querySelector(".jstree-children");
    if (childrenItem) {
      lookupAndReplaceText(childrenItem);
    }
  });
}

function listenOnTreeChange(rootTree, onChange) {
  const observer = new MutationObserver(() => {
    onChange();
  });
  observer.observe(rootTree, { childList: true, subtree: true });
}

function doUntilSuccess(action) {
  if (action()) {
    return;
  }

  const intervalId = setInterval(() => {
    if (action()) {
      clearInterval(intervalId);
    }
  }, 100);
}

function lookupAndReplaceAll() {
  const panel = document.getElementById("leftPanels");
  if (panel && panel.style.display !== "none") {
    doUntilSuccess(() => {
      const root = document.querySelector("#leftPanels .jstree-children");
      if (root && root.querySelectorAll('[role="treeitem"]').length > 0) {
        listenOnTreeChange(panel, () => {
          lookupAndReplaceText(document.querySelector("#leftPanels .jstree-children"));
        });
        lookupAndReplaceText(root);
        return true;
      }

      return false;
    });
  }

  document.querySelectorAll('.search-ui .search-result-title').forEach(el => {
    replaceNodeText(el);
  });
  document.querySelectorAll('.search-ui .search-result-highlight').forEach(el => {
    replaceNodeText(el);
  });
  document.querySelectorAll('.search-ui .search-result-location .breadcrumb > li').forEach(el => {
    replaceNodeText(el);
  });

  doUntilSuccess(() => {
    const pageTitle = document.getElementById("document-title");
    if (pageTitle) {
      replaceNodeText(pageTitle);

      document.title = document.title.replace(testPattern, "").trim();
    }

    return !!pageTitle;
  });

  doUntilSuccess(() => {
      const breadcrumb = document.querySelectorAll('#hierarchy .dropdown');
      if (breadcrumb.length === 0) {
          return false;
      }

      breadcrumb.forEach(el => {
        replaceNodeText(el);

        const menu = el.querySelector('.dropdown-menu');
        if (menu) {
            listenOnTreeChange(menu, () => {
                lookupAndReplaceText(menu);
            })
        }
      })

      return true;
  })
}

lookupAndReplaceAll();

document.querySelectorAll(".breadcrumb-tree").forEach(el => {
  el.setAttribute('data-responsive', 'false');
  if (el.parentElement.classList.contains('dropdown-menu')) {
    el.parentElement.style.maxHeight = 'calc(100vh - 150px)';
    el.parentElement.style.overflow = 'auto';
  }
});

document.querySelectorAll("#leftPanels > .xtree[data-responsive]").forEach(el => {
  el.setAttribute('data-responsive', 'false');
});
const overviewLink = document.querySelector(".space.dropdown > a[href='/bin/view/Overview/']");
if (overviewLink && overviewLink.parentElement) {
  overviewLink.parentElement.classList.add('breadcrumb--disabled');
}
const {pathname} = window.location;
if (pathname.startsWith('/bin/loginsubmit') || pathname.startsWith('/bin/login')) {
  document.title = 'Login - akaBot Docs';
}
(() => {
  function disableModal() {
    let opened = false;
    let buttons = [];

    function handleExportClick(event) {
      if (event.target.hasAttribute("disabled")) {
        event.stopImmediatePropagation();
        event.stopPropagation();
        event.preventDefault();
      } else {
        event.target.setAttribute("disabled", "true");
      }
    }

    function onShow(modal) {
      console.log("onshow");
      modal.querySelectorAll("a.btn.btn-primary").forEach((button) => {
        buttons.push(button);
        button.addEventListener("click", handleExportClick);
      });
    }

    function onHide() {
      console.log("onhide");
      buttons.forEach((button) => {
        button.removeAttribute("disabled");
        button.removeEventListener("click", handleExportClick);
      });
      buttons = [];
    }

    setInterval(() => {
      const modal = document.getElementById("exportModal");
      if (modal) {
        const isOpen = modal.style.display === "block";
        if (isOpen && !opened) {
          onShow(modal);
        } else if (!isOpen && opened) {
          onHide();
        }
        opened = isOpen;
      }
    }, 1000);
  }

  function disablePDFExport() {
    const pdfPanel = document.getElementById("pdfExportOptions");
    if (pdfPanel) {
      const button = pdfPanel.querySelector('input.button[type="submit"]');
      if (button) {
        button.addEventListener("click", () => {
          setTimeout(() => {
            button.setAttribute("disabled", "true");
          });
        });
      }
    }
  }

  const url = new URLSearchParams(location.search);
  if (url.get("xpage") !== "pdfoptions") {
    disableModal();
  } else {
    disablePDFExport();
  }
})();
